#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'tab-bar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/tab-bar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tab-bar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__tab_bar_t {
    QByteArrayData data[8];
    char stringdata0[119];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__tab_bar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__tab_bar_t qt_meta_stringdata_octave__tab_bar = {
    {
QT_MOC_LITERAL(0, 0, 15), // "octave::tab_bar"
QT_MOC_LITERAL(1, 16, 24), // "close_current_tab_signal"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 15), // "switch_left_tab"
QT_MOC_LITERAL(4, 58, 16), // "switch_right_tab"
QT_MOC_LITERAL(5, 75, 13), // "move_tab_left"
QT_MOC_LITERAL(6, 89, 14), // "move_tab_right"
QT_MOC_LITERAL(7, 104, 14) // "sort_tabs_alph"

    },
    "octave::tab_bar\0close_current_tab_signal\0"
    "\0switch_left_tab\0switch_right_tab\0"
    "move_tab_left\0move_tab_right\0"
    "sort_tabs_alph"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__tab_bar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   47,    2, 0x0a /* Public */,
       4,    0,   48,    2, 0x0a /* Public */,
       5,    0,   49,    2, 0x0a /* Public */,
       6,    0,   50,    2, 0x0a /* Public */,
       7,    0,   51,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::tab_bar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        tab_bar *_t = static_cast<tab_bar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->close_current_tab_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->switch_left_tab(); break;
        case 2: _t->switch_right_tab(); break;
        case 3: _t->move_tab_left(); break;
        case 4: _t->move_tab_right(); break;
        case 5: _t->sort_tabs_alph(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (tab_bar::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&tab_bar::close_current_tab_signal)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject octave::tab_bar::staticMetaObject = {
    { &QTabBar::staticMetaObject, qt_meta_stringdata_octave__tab_bar.data,
      qt_meta_data_octave__tab_bar,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::tab_bar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::tab_bar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__tab_bar.stringdata0))
        return static_cast<void*>(this);
    return QTabBar::qt_metacast(_clname);
}

int octave::tab_bar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void octave::tab_bar::close_current_tab_signal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
